result

# XMLRésuméLibrary: User Guide

referees | Element Reference | resume

## Name

result — An outcome of a subject

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `result` element describes the outcome or result of a `subject`. `result` often contains the letter or numeric grade awarded for an academic class.

### Parents

`result` may be contained in these elements: `subject`

## Examples

    <subjects>
      <subject>
        <title>Math</title>
        <result>A-</result>
      </subject>
      <subject>
        <title>English</title>
        <result>C</result>
      </subject>
      <subject>
        <title>Science</title>
        <result>B+</result>
      </subject>
      <subject>
        <title>Spanish</title>
        <result>B</result>
      </subject>
    </subjects>

referees | Element Reference | resume